diff tests/automated/mule-tests.el @ 4948:8b230c53075b

fix some tests in `make check', also add our own file-tests -------------------- ChangeLog entries follow: -------------------- lisp/ChangeLog addition: 2010-01-25 Ben Wing <ben@xemacs.org> * mule/cyrillic.el (koi8-c): Fix bug in #83 mapping. * mule/vietnamese.el (viscii): Fix bug in #A6 mapping. tests/ChangeLog addition: 2010-01-25 Ben Wing <ben@xemacs.org> * automated/file-tests.el: New file. * automated/mule-tests.el (featurep): * automated/test-harness.el (test-harness-from-buffer): * automated/test-harness.el (batch-test-emacs):
author Ben Wing <ben@xemacs.org>
date Mon, 25 Jan 2010 03:03:49 -0600
parents 1f3ed6288996
children db2db229ee82
line wrap: on
line diff
--- a/tests/automated/mule-tests.el	Mon Jan 25 02:48:52 2010 -0600
+++ b/tests/automated/mule-tests.el	Mon Jan 25 03:03:49 2010 -0600
@@ -551,25 +551,20 @@
   ;;---------------------------------------------------------------
   (with-temp-buffer
     (insert-file-contents (locate-data-file "HELLO"))
-    (Assert-equal 
-             ;; The sort is to make the algorithm of charsets-in-region
-             ;; irrelevant.
-             (sort (charsets-in-region (point-min) (point-max))
-                   #'string<)
-             '(ascii chinese-big5-1 chinese-gb2312 cyrillic-iso8859-5
-               ethiopic greek-iso8859-7 hebrew-iso8859-8 japanese-jisx0208
-               japanese-jisx0212 jit-ucs-charset-0 katakana-jisx0201
-               korean-ksc5601 latin-iso8859-1 latin-iso8859-2 thai-xtis
-               vietnamese-viscii-lower))
-    (Assert-equal 
-             (sort (charsets-in-string (buffer-substring (point-min)
-							 (point-max)))
-                   #'string<)
-             '(ascii chinese-big5-1 chinese-gb2312 cyrillic-iso8859-5
-               ethiopic greek-iso8859-7 hebrew-iso8859-8 japanese-jisx0208
-               japanese-jisx0212 jit-ucs-charset-0 katakana-jisx0201
-               korean-ksc5601 latin-iso8859-1 latin-iso8859-2 thai-xtis
-               vietnamese-viscii-lower)))
+    (let ((expected
+	   '(arabic-iso8859-6 ascii chinese-big5-1 chinese-gb2312
+	     cyrillic-iso8859-5 ethiopic greek-iso8859-7 hebrew-iso8859-8
+	     japanese-jisx0208 japanese-jisx0212 katakana-jisx0201
+	     korean-ksc5601 latin-iso8859-1 latin-iso8859-2
+	     thai-xtis vietnamese-viscii-lower)))
+      (Assert-equal
+       ;; The sort is to make the algorithm of charsets-in-region
+       ;; irrelevant.
+       (sort (charsets-in-region (point-min) (point-max))
+	     #'string<) expected)
+      (Assert-equal 
+       (sort (charsets-in-string (buffer-substring (point-min) (point-max)))
+	     #'string<) expected)))
 
   ;;---------------------------------------------------------------
   ;; Language environments, and whether the specified values are sane.